@@ -14,7 +14,6 @@
 from oslo_config import cfg
 from oslo_log import log
 import oslo_messaging
-import six
 
 from aodh import messaging
 from aodh.storage import models
@@ -35,7 +34,7 @@ class AlarmNotifier(object):
             messaging.get_transport(conf),
             driver='messagingv2',
             publisher_id="alarming.evaluator",
-            topic=conf.notifier_topic)
+            topics=[conf.notifier_topic])
 
     def notify(self, alarm, previous, reason, reason_data):
         actions = getattr(alarm, models.Alarm.ALARM_ACTIONS_MAP[alarm.state])
@@ -53,6 +52,6 @@ class AlarmNotifier(object):
                    'severity': alarm.severity,
                    'previous': previous,
                    'current': alarm.state,
-                   'reason': six.text_type(reason),
+                   'reason': str(reason),
                    'reason_data': reason_data}
         self.notifier.sample({}, 'alarm.update', payload)
